summaryrefslogtreecommitdiffstats
path: root/src/gui/configuration/ConfigurationPage.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/gui/configuration/ConfigurationPage.h')
-rw-r--r--src/gui/configuration/ConfigurationPage.h12
1 files changed, 6 insertions, 6 deletions
diff --git a/src/gui/configuration/ConfigurationPage.h b/src/gui/configuration/ConfigurationPage.h
index bf0ccd9..cc23da5 100644
--- a/src/gui/configuration/ConfigurationPage.h
+++ b/src/gui/configuration/ConfigurationPage.h
@@ -32,7 +32,7 @@
#include <tqwidget.h>
-class KConfig;
+class TDEConfig;
namespace Rosegarden
@@ -55,11 +55,11 @@ public:
TQWidget *parent=0, const char *name=0)
: TQWidget(parent, name), m_doc(doc), m_cfg(0), m_pageIndex(0) {}
- ConfigurationPage(KConfig *cfg,
+ ConfigurationPage(TDEConfig *cfg,
TQWidget *parent=0, const char *name=0)
: TQWidget(parent, name), m_doc(0), m_cfg(cfg), m_pageIndex(0) {}
- ConfigurationPage(RosegardenGUIDoc *doc, KConfig *cfg,
+ ConfigurationPage(RosegardenGUIDoc *doc, TDEConfig *cfg,
TQWidget *parent=0, const char *name=0)
: TQWidget(parent, name), m_doc(doc), m_cfg(cfg), m_pageIndex(0) {}
@@ -67,14 +67,14 @@ public:
/**
* Should set the page up (ie. read the setting from the @ref
* KConfig object into the widgets) after creating it in the
* constructor. Called from @ref ConfigureDialog.
*/
// virtual void setup() = 0;
/**
* Should apply the changed settings (ie. read the settings from
* the widgets into the @ref KConfig object). Called from @ref
* ConfigureDialog.
*/
virtual void apply() = 0;
@@ -94,7 +94,7 @@ protected:
//--------------- Data members ---------------------------------
RosegardenGUIDoc* m_doc;
- KConfig* m_cfg;
+ TDEConfig* m_cfg;
int m_pageIndex;
};
@@ -67,14 +67,14 @@ public:
/**
* Should set the page up (ie. read the setting from the @ref
- * KConfig object into the widgets) after creating it in the
+ * TDEConfig object into the widgets) after creating it in the
* constructor. Called from @ref ConfigureDialog.
*/
@@ -67,14 +67,14 @@ public:
/**
* Should apply the changed settings (ie. read the settings from
- * the widgets into the @ref KConfig object). Called from @ref
+ * the widgets into the @ref TDEConfig object). Called from @ref
* ConfigureDialog.
*/